NaMaster: nmt_covar_workspace Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_covar_workspace Struct Reference

Full-sky Gaussian covariance matrix. More...

`#include <namaster.h>`

## Data Fields
int | lmax
| Maximum multipole for the first set of power spectra. More...
flouble ** | xi00_1122
| First (a1b1-a2b2), 00, mode coupling matrix (see scientific documentation) More...
flouble ** | xi00_1221
| Second (a1b2-a2b1), 00, mode coupling matrix (see scientific documentation) More...
flouble ** | xi02_1122
| First (a1b1-a2b2), 02, mode coupling matrix (see scientific documentation) More...
flouble ** | xi02_1221
| Second (a1b2-a2b1), 02, mode coupling matrix (see scientific documentation) More...
flouble ** | xi22p_1122
| First (a1b1-a2b2), 22+, mode coupling matrix (see scientific documentation) More...
flouble ** | xi22p_1221
| Second (a1b2-a2b1), 22+, mode coupling matrix (see scientific documentation) More...
flouble ** | xi22m_1122
| First (a1b1-a2b2), 22-, mode coupling matrix (see scientific documentation) More...
flouble ** | xi22m_1221
| Second (a1b2-a2b1), 22-, mode coupling matrix (see scientific documentation) More...

## Detailed Description

Full-sky Gaussian covariance matrix.

Structure containing the information necessary to compute Gaussian covariance matrices for the pseudo-CL spectra of two full-sky spin-0 fields.

## Field Documentation

int nmt_covar_workspace::lmax

Maximum multipole for the first set of power spectra.

flouble** nmt_covar_workspace::xi00_1122

First (a1b1-a2b2), 00, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi00_1221

Second (a1b2-a2b1), 00, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi02_1122

First (a1b1-a2b2), 02, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi02_1221

Second (a1b2-a2b1), 02, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi22m_1122

First (a1b1-a2b2), 22-, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi22m_1221

Second (a1b2-a2b1), 22-, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi22p_1122

First (a1b1-a2b2), 22+, mode coupling matrix (see scientific documentation)

flouble** nmt_covar_workspace::xi22p_1221

Second (a1b2-a2b1), 22+, mode coupling matrix (see scientific documentation)

The documentation for this struct was generated from the following file:

- namaster.h